Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 103456 Série: 508 Data de Emissão: 27/04/2019 20:30:03
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0475 3153 3301 2115 6550 8000 1034 5610 4857 9173
Protocolo de Autorização: 143190572294814
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
14201952 | LEITE L.VIDA MOLICO | 4 | UN | 3,2 | 12,80
41497915 | ERVA MATE SAPHIRA | 1 | UN | 8,79 | 8,79
55374981 | CR.DENTAL COLGATE | 1 | UN | 27,45 | 27,45
46505956 | GOMA MANDIOCA BEIJU | 2 | UN | 5,99 | 11,98
11874800 | FEIJAO KICALDO | 1 | UN | 6,1 | 6,10
61164927 | ACUCAR MASCAVO | 1 | UN | 9,98 | 9,98
54636962 | BISC.CLUB SOCIAL | 1 | UN | 5,18 | 5,18
51583990 | SAC INST.BIO 60X70 | 2 | UN | 0,2 | 0,40
3186904 | AVEIA NATUS FLOCOS | 2 | UN | 5,15 | 10,30
28999978 | EXTRATO FUGINI POUCH | 2 | UN | 1,79 | 3,58
9961968 | MAC.ORQUIDEA | 1 | UN | 2,28 | 2,28
59113962 | RF.QUEIJO PRATO FAT. | 1 | UN | 12,98 | 12,98
59114921 | QJO MUSS.FAT.FRIMES | 1 | UN | 12,98 | 12,98
8709976 | TOMATE S/PEL.MASTRO. | 3 | UN | 3,95 | 11,85
54149963 | TOMATE S/PELE CUBOS | 2 | UN | 2,25 | 4,50
28850933 | AGUA M.FLORESTA PET | 4 | UN | 4,29 | 17,16
23914965 | AGUA COCO SOCOCO | 1 | UN | 6,99 | 6,99
55748948 | OLEO COCO DUCOCO | 1 | UN | 12,9 | 12,90
34320950 | MACA DISNEY | 1 | UN | 5,5 | 5,50
41213970 | LEITE FERM.ACTIVIA | 1 | UN | 10,99 | 10,99
41552997 | CAFE BOM JESUS VAC.T | 1 | UN | 8,4 | 8,40
28865914 | MASSA PIZZA ROMENA | 3 | UN | 2,99 | 8,97
32150906 | PAO FORMA S.BOYS | 1 | UN | 4,6 | 4,60
41208971 | LEITE FERM.ACTIVIA M | 1 | UN | 10,99 | 10,99
25606910 | MANT.ELEGE TABLETE | 1 | UN | 5,99 | 5,99
41666903 | CREME LEITE TIROL | 2 | UN | 1,89 | 3,78
28961968 | CHA BARAO VERDE | 2 | UN | 2,4 | 4,80
39425934 | FILTRO.CAFE BRIGITTA | 1 | UN | 2,99 | 2,99
13347932 | LARANJA MIMO DO CEU | 1,626 | KG | 7,3 | 11,87
7081919 | AZEITE GALLO VDO | 1 | UN | 17,49 | 17,49
63424984 | VINAGRE ROSINA FRUTA | 1 | UN | 2,45 | 2,45
64141987 | MAC.ORQ.ESPAGUETE | 1 | UN | 2,39 | 2,39
62248998 | ATUM ROBINSON | 4 | UN | 4,29 | 17,16
62246979 | ATUM ROBINSON CRUSOE | 4 | UN | 5,19 | 20,76
53895956 | RF.CARNE MOIDA BDJ | 1 | UN | 10,65 | 10,65
36874148 | KIWI | 3 | UN | 5,6 | 16,80
58250984 | LASANHA BOLONHESA | 1 | UN | 14,5 | 14,50
Valor total R$ | 358,08
Valor descontos R$ | 1,20
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:46